@@ -1,4 +1,5 @@
 #![forbid(unsafe_code)]
+#![warn(clippy::needless_pass_by_value)]
 
 mod ast;
 pub mod errors;
@@ -13,7 +14,9 @@ use utils::format_line_comments;
 /**
 Compiles Melody source code to a regular expression.
 
-see also: [`ParseError`]
+# Errors
+
+Returns a [`ParseError`] upon encountering a syntax error
 
 # Example
 
